#!/bin/sh
set -e

if [ "$#" != "2" ]; then
  echo "\
  Wrong number of arguments: '$#' \
  This script takes two arguments: <Old kernel version> <New kernel version>"
  exit 1
fi
OLD=$1
NEW=$2
AREA='/usr/src/trustix'
SPEC="$AREA/specs/kernel-2.4.spec"
BUILD="$AREA/build/linux-$2"
GENERATED=""

# Finding old configs:
echo "Finding old ($OLD) config files in $AREA/sources:"
sleep 2
CONFIGS=$(find $AREA/sources -name kernel-$OLD-i586\*.config)

# Preparing the build area:
echo "Running 'rpm -bp $SPEC':"
sleep 2
rpm -bp $SPEC

# Config loop:
echo "Moving to $BUILD:"
cd $BUILD
echo "Doing the config loop:"
for conf in $CONFIGS; do
    NEWCONF=$(echo $conf | sed "s|$OLD|$NEW|")
    echo "Copying $conf to .config"
    cp $conf .config
    echo "Running make oldconfig:"
    sleep 2
    make oldconfig
    echo "Copying modified .config to $NEWCONF"
    cp .config $NEWCONF
    GENERATED="$GENERATED $NEWCONF"
done
echo "The following files was generated:"
for i in $GENERATED; do 
    echo $i
done
echo "Finito."
